@@ -9,9 +9,6 @@ import publication
 import typing_extensions
 
 import aws_cdk.aws_apigateway._jsii
-import aws_cdk.aws_apigatewayv2._jsii
-import aws_cdk.aws_apigatewayv2_integrations._jsii
-import aws_cdk.aws_batch._jsii
 import aws_cdk.aws_cloudwatch._jsii
 import aws_cdk.aws_codebuild._jsii
 import aws_cdk.aws_databrew._jsii
@@ -33,9 +30,9 @@ import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@aws-cdk/aws-stepfunctions-tasks",
-    "1.99.0",
+    "1.100.0",
     __name__[0:-6],
-    "aws-stepfunctions-tasks@1.99.0.jsii.tgz",
+    "aws-stepfunctions-tasks@1.100.0.jsii.tgz",
 )
 
 __all__ = [
